==> rc-ui-lib-0.1.41.tgz: package/es/share-sheet/ShareSheet.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import React, { useContext } from 'react';
import cls from 'classnames';
import { pick } from '../utils';
import Popup from '../popup';
import ConfigProviderContext from '../config-provider/ConfigProviderContext';
var PRESET_ICONS = ['qq', 'link', 'weibo', 'wechat', 'poster', 'qrcode', 'weapp-qrcode', 'wechat-moments'];

function getIconURL(icon) {
  if (PRESET_ICONS.includes(icon)) {
    return "https://img.yzcdn.cn/vant/share-sheet-".concat(icon, ".png");
  }

  return icon;
}

var ShareSheet = function ShareSheet(props) {
  var _useContext = useContext(ConfigProviderContext),
      prefixCls = _useContext.prefixCls,
      createNamespace = _useContext.createNamespace;

  var _createNamespace = createNamespace('share-sheet', prefixCls),
      _createNamespace2 = _slicedToArray(_createNamespace, 1),
      bem = _createNamespace2[0];

  var onCancel = function onCancel() {
    var _props$onCancel;

    (_props$onCancel = props.onCancel) === null || _props$onCancel === void 0 ? void 0 : _props$onCancel.call(props);
  };

  var onSelect = function onSelect(option, index) {
    var _props$onSelect;

    (_props$onSelect = props.onSelect) === null || _props$onSelect === void 0 ? void 0 : _props$onSelect.call(props, option, index);
  };

  var renderHeader = function renderHeader() {
    var title = props.title,
        description = props.description;

    if (title || description) {
      return /*#__PURE__*/React.createElement("div", {
        className: cls(bem('header'))
      }, title && /*#__PURE__*/React.createElement("div", {
        className: cls(bem('title'))
      }, title), description && /*#__PURE__*/React.createElement("div", {
        className: cls(bem('description'))
      }, description));
    }

    return null;
  };

  var renderOption = function renderOption(option, index) {
    var name = option.name,
        icon = option.icon,
        className = option.className,
        description = option.description;
    return /*#__PURE__*/React.createElement("div", {
      key: index,
      role: "button",
      tabIndex: 0,
      className: cls([bem('option'), className]),
      onClick: function onClick() {
        return onSelect(option, index);
      }
    }, /*#__PURE__*/React.createElement("img", {
      alt: "share sheet icon",
      src: getIconURL(icon),
      className: cls(bem('icon'))
    }), name && /*#__PURE__*/React.createElement("span", {
      className: cls(bem('name'))
    }, name), description && /*#__PURE__*/React.createElement("span", {
      className: cls(bem('option-description'))
    }, description));
  };

  var renderOptions = function renderOptions(options, border, key) {
    return /*#__PURE__*/React.createElement("div", {
      key: key,
      className: cls(bem('options', {
        border: border
      }))
    }, options.map(renderOption));
  };

  var renderRows = function renderRows() {
    var options = props.options;

    if (Array.isArray(options[0])) {
      return options.map(function (item, index) {
        return renderOptions(item, index !== 0, index);
      });
    }

    return renderOptions(options);
  };

  var renderCancelButton = function renderCancelButton() {
    var cancelText = props.cancelText;

    if (cancelText) {
      return /*#__PURE__*/React.createElement("button", {
        type: "button",
        className: cls(bem('cancel')),
        onClick: onCancel
      }, cancelText);
    }

    return null;
  };

  return /*#__PURE__*/React.createElement(Popup, _extends({
    round: true,
    className: cls(bem()),
    position: "bottom",
    onClose: onCancel
  }, pick(props, ['closeOnPopstate', 'safeAreaInsetBottom', 'visible', 'overlay', 'duration', 'lockScroll', 'overlayStyle', 'overlayClass', 'closeOnClickOverlay'])), renderHeader(), renderRows(), renderCancelButton());
};

ShareSheet.defaultProps = {
  cancelText: '取消',
  options: [],
  closeOnPopstate: true,
  safeAreaInsetBottom: true,
  closeOnClickOverlay: true
};
export default ShareSheet;

==> rc-ui-lib-1.3.4.tgz: package/es/share-sheet/ShareSheet.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import React, { useContext } from 'react';
import classnames from 'classnames';
import { pick } from '../utils';
import Popup from '../popup';
import ConfigProviderContext from '../config-provider/ConfigProviderContext';
var PRESET_ICONS = ['qq', 'link', 'weibo', 'wechat', 'poster', 'qrcode', 'weapp-qrcode', 'wechat-moments'];

function getIconURL(icon) {
  if (PRESET_ICONS.includes(icon)) {
    return "https://img.yzcdn.cn/vant/share-sheet-".concat(icon, ".png");
  }

  return icon;
}

var ShareSheet = function ShareSheet(props) {
  var _useContext = useContext(ConfigProviderContext),
      prefixCls = _useContext.prefixCls,
      createNamespace = _useContext.createNamespace;

  var _createNamespace = createNamespace('share-sheet', prefixCls),
      _createNamespace2 = _slicedToArray(_createNamespace, 1),
      bem = _createNamespace2[0];

  var onCancel = function onCancel() {
    var _props$onCancel;

    (_props$onCancel = props.onCancel) === null || _props$onCancel === void 0 ? void 0 : _props$onCancel.call(props);
  };

  var onSelect = function onSelect(option, index) {
    var _props$onSelect;

    (_props$onSelect = props.onSelect) === null || _props$onSelect === void 0 ? void 0 : _props$onSelect.call(props, option, index);
  };

  var renderHeader = function renderHeader() {
    var title = props.title,
        description = props.description;

    if (title || description) {
      return /*#__PURE__*/React.createElement("div", {
        className: classnames(bem('header'))
      }, title && /*#__PURE__*/React.createElement("div", {
        className: classnames(bem('title'))
      }, title), description && /*#__PURE__*/React.createElement("div", {
        className: classnames(bem('description'))
      }, description));
    }

    return null;
  };

  var renderOption = function renderOption(option, index) {
    var name = option.name,
        icon = option.icon,
        className = option.className,
        description = option.description;
    return /*#__PURE__*/React.createElement("div", {
      key: index,
      role: "button",
      tabIndex: 0,
      className: classnames([bem('option'), className]),
      onClick: function onClick() {
        return onSelect(option, index);
      }
    }, /*#__PURE__*/React.createElement("img", {
      alt: "share sheet icon",
      src: getIconURL(icon),
      className: classnames(bem('icon'))
    }), name && /*#__PURE__*/React.createElement("span", {
      className: classnames(bem('name'))
    }, name), description && /*#__PURE__*/React.createElement("span", {
      className: classnames(bem('option-description'))
    }, description));
  };

  var renderOptions = function renderOptions(options, border, key) {
    return /*#__PURE__*/React.createElement("div", {
      key: key,
      className: classnames(bem('options', {
        border: border
      }))
    }, options.map(renderOption));
  };

  var renderRows = function renderRows() {
    var options = props.options;

    if (Array.isArray(options[0])) {
      return options.map(function (item, index) {
        return renderOptions(item, index !== 0, index);
      });
    }

    return renderOptions(options);
  };

  var renderCancelButton = function renderCancelButton() {
    var cancelText = props.cancelText;

    if (cancelText) {
      return /*#__PURE__*/React.createElement("button", {
        type: "button",
        className: classnames(bem('cancel')),
        onClick: onCancel
      }, cancelText);
    }

    return null;
  };

  return /*#__PURE__*/React.createElement(Popup, _extends({
    round: true,
    className: classnames(bem()),
    position: "bottom",
    onClose: onCancel
  }, pick(props, ['closeOnPopstate', 'safeAreaInsetBottom', 'visible', 'overlay', 'duration', 'lockScroll', 'overlayStyle', 'overlayClass', 'closeOnClickOverlay'])), renderHeader(), renderRows(), renderCancelButton());
};

ShareSheet.defaultProps = {
  cancelText: '取消',
  options: [],
  closeOnPopstate: true,
  safeAreaInsetBottom: true,
  closeOnClickOverlay: true
};
export default ShareSheet;
